@@ -1,9 +1,9 @@
-from ._cftime import utime, JulianDayFromDate, DateFromJulianDay
+from ._cftime import utime, JulianDayFromDate, DateFromJulianDay, UNIT_CONVERSION_FACTORS
 from ._cftime import _parse_date, date2index, time2index
 from ._cftime import datetime, real_datetime
 from ._cftime import DatetimeNoLeap, DatetimeAllLeap, Datetime360Day, DatetimeJulian, \
                          DatetimeGregorian, DatetimeProlepticGregorian
 from ._cftime import microsec_units, millisec_units, \
                          sec_units, hr_units, day_units, min_units
-from ._cftime import num2date, date2num, date2index
+from ._cftime import num2date, date2num, date2index, num2pydate
 from ._cftime import __version__
